<?php


/*  Copyright 2014 The Web Squad







    This program is free software; you can redistribute it and/or modify



    it under the terms of the GNU General Public License, version 2, as 



    published by the Free Software Foundation.







    This program is distributed in the hope that it will be useful,



    but WITHOUT ANY WARRANTY; without even the implied warranty of



    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the



    GNU General Public License for more details.







    You should have received a copy of the GNU General Public License



    along with this program; if not, write to the Free Software



    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA



*/


// Adds custom post type for Slides


add_action( 'init', 'wsslides_register_slides' );


function wsslides_register_slides() {


  $ws_labels = array(


    'name' => __( 'Slides', 'ws-slides' ),


    'singular_name' => __( 'Slide', 'ws-slides' ),


    'add_new' => __( 'Add New', 'ws-slides' ),


    'add_new_item' => __( 'Add New Slide', 'ws-slides' ),


    'edit_item' => __( 'Edit Slide', 'ws-slides' ),


    'new_item' => __( 'New Slide', 'ws-slides' ),


    'view_item' => __( 'View Slide', 'ws-slides' ),


    'search_items' => __( 'Search Slides', 'ws-slides' ),


    'not_found' => __( 'No slides found', 'ws-slides' ),


    'not_found_in_trash' => __( 'No slides found in Trash', 'ws-slides' ),


    'parent_item_colon' => '',


    'menu_name' => __( 'WS Slides', 'ws-slides' )


  );


  if ( function_exists( 'members_get_capabilities' ) ) {


    $ws_capabilities = array(


      'edit_post' => 'wsslides_edit_slide',


      'edit_posts' => 'wsslides_edit_slides',


      'edit_others_posts' => 'wsslides_edit_others_slides',


      'publish_posts' => 'wsslides_publish_slides',


      'read_post' => 'wsslides_read_slide',


      'read_private_posts' => 'wsslides_read_private_slides',


      'delete_post' => 'wsslides_delete_slide'


    );


    $ws_capabilitytype = 'slide';


    $ws_mapmetacap = false;


  } else {


    $ws_capabilities = array(


      'edit_post' => 'edit_post',


      'edit_posts' => 'edit_posts',


      'edit_others_posts' => 'edit_others_posts',


      'publish_posts' => 'publish_posts',


      'read_post' => 'read_post',


      'read_private_posts' => 'read_private_posts',


      'delete_post' => 'delete_post'


    );


    $ws_capabilitytype = 'post';


    $ws_mapmetacap = true;


  }


  $ws_args = array(


    'labels' => $ws_labels,


    'public' => true,


    'publicly_queryable' => false,


    'exclude_from_search' => true,


    'show_ui' => true,


    'show_in_menu' => true,


    'menu_icon' => '' . get_template_directory_uri() . '/scripts/ws-slides/images/slides-icon-20x20.png',


    'capability_type' => $ws_capabilitytype,


    'capabilities' => $ws_capabilities,


    'map_meta_cap' => $ws_mapmetacap,


    'hierarchical' => false,


    'supports' => array( 'title', 'thumbnail' ),


    'taxonomies' => array( 'slideshow' ),


    'has_archive' => false,


    'rewrite' => false,


    'query_var' => true,


    'can_export' => true,


    'show_in_nav_menus' => false


  );


  register_post_type( 'slide', $ws_args );


}


// Adds custom taxonomy for Slideshows


add_action( 'init', 'wsslides_register_taxonomy' );


function wsslides_register_taxonomy() {


  $ws_tax_labels = array(


    'name' => __( 'Slideshows', 'ws-slides' ),


    'singular_name' => __( 'Slideshow', 'ws-slides' ),


    'search_items' => __( 'Search Slideshows', 'ws-slides' ),


    'popular_items' => __( 'Popular Slideshows', 'ws-slides' ),


    'all_items' => __( 'All Slideshows', 'ws-slides' ),


    'parent_item' => __( 'Parent Slideshow', 'ws-slides' ),


    'parent_item_colon' => __( 'Parent Slideshow:', 'ws-slides' ),


    'edit_item' => __( 'Edit Slideshow', 'ws-slides' ),


    'update_item' => __( 'Update Slideshow', 'ws-slides' ),


    'add_new_item' => __( 'Add New Slideshow', 'ws-slides' ),


    'new_item_name' => __( 'New Slideshow Name', 'ws-slides' ),


    'menu_name' => __( 'Slideshows', 'ws-slides' )


  );


  if ( function_exists( 'members_get_capabilities' ) ) {


    $ws_tax_capabilities = array(


      'manage_terms' => 'wsslides_manage_slideshows',


      'edit_terms' => 'wsslides_manage_slideshows',


      'delete_terms' => 'wsslides_manage_slideshows',


      'assign_terms' => 'wsslides_edit_slides'


    );


  } else {


    $ws_tax_capabilities = array(


      'manage_terms' => 'manage_categories',


      'edit_terms' => 'manage_categories',


      'delete_terms' => 'manage_categories',


      'assign_terms' => 'edit_posts'


    );


  }


  $ws_tax_args = array(


    'labels' => $ws_tax_labels,


    'public' => true,


    'show_in_nav_menus' => false,


    'show_ui' => true,


    'show_tagcloud' => false,


    'hierarchical' => true,


    'rewrite' => array( 'slug' => 'slideshow' ),


    'capabilities' => $ws_tax_capabilities


  );


  register_taxonomy( 'slideshow', 'slide', $ws_tax_args );


}


// Adds featured image functionality for Slides


add_action( 'after_setup_theme', 'wsslides_featured_image_array', '9999' );


function wsslides_featured_image_array() {


  global $_wp_theme_features;


  if ( !isset( $_wp_theme_features[ 'post-thumbnails' ] ) ) {


    $_wp_theme_features[ 'post-thumbnails' ] = array( array( 'slide' ) );


  } elseif ( is_array( $_wp_theme_features[ 'post-thumbnails' ] ) ) {


    $_wp_theme_features[ 'post-thumbnails' ][ 0 ][] = 'slide';


  }


}


// Adds featured image size for Slides


add_action( 'plugins_loaded', 'wsslides_featured_image' );


function wsslides_featured_image() {


  $ws_options = get_option( 'wsslides_options' );


  add_image_size( 'featured-slide', $ws_options[ 'slide_width' ], $ws_options[ 'slide_height' ], true );


  add_image_size( 'featured-slide-thumb', 250, 9999 );


}


// Adds CSS for the slideshow


add_action( 'wp_enqueue_scripts', 'wsslides_css' );


function wsslides_css() {


  wp_enqueue_style( 'ws-slides', get_stylesheet_directory_uri() . '/scripts/ws-slides/css/ws-slides.css', array(), '1.0' );


}


// Adds JavaScript for the slideshow


add_action( 'wp_print_scripts', 'wsslides_javascript' );


function wsslides_javascript() {


  $ws_options = get_option( 'wsslides_options' );


  if ( !is_admin() ) {


    wp_enqueue_script( 'jquery' );


    wp_enqueue_script( 'jquery-cycle', get_stylesheet_directory_uri() . '/scripts/ws-slides/js/jquery.cycle.all.js', array( 'jquery' ) );


    wp_enqueue_script( 'jquery-metadata', get_stylesheet_directory_uri() . '/scripts/ws-slides/js/jquery.metadata.v2.js', array( 'jquery' ) );


    wp_enqueue_script( 'jquery-touchwipe', get_stylesheet_directory_uri() . '/scripts/ws-slides/js/jquery.touchwipe.1.1.1.js', array( 'jquery' ) );


    wp_enqueue_script( 'wsslides-script', get_stylesheet_directory_uri() . '/scripts/ws-slides/js/slideshow.js', array( 'jquery', 'jquery-cycle' ) );


    wp_localize_script( 'wsslides-script', 'wsslidessettings',


      array(


        'wsslideshowspeed' => $ws_options[ 'transition_speed' ] * 1000,


        'wsslideshowduration' => $ws_options[ 'slide_duration' ] * 1000,


        //'wsslideshowheight'     => $ws_options['slide_height'],


        //'wsslideshowwidth'      => $ws_options['slide_width'],


        'wsslideshowboxheight' => $ws_options[ 'slidebox_height' ],


        'wsslideshowboxwidth' => $ws_options[ 'slidebox_width' ],


        'wsslideshowtransition' => $ws_options[ 'transition_style' ]


      )


    );


  }


}


// Load admin functions if in the backend


if ( is_admin() ) {


  require_once( 'includes/ws-slides-admin.php' );


}


// Adds default values for options on settings page


register_activation_hook( __FILE__, 'wsslides_default_options' );


function wsslides_default_options() {


  $ws_temp = get_option( 'wsslides_options' );


  if ( ( $ws_temp[ 'slideshow_quantity' ] == '' ) || ( !is_array( $ws_temp ) ) ) {


    $ws_defaults_args = array(


      'slideshow_quantity' => '5',


      'slide_height' => '500',


      'slide_width' => '1000',


      'slidebox_height' => '500',


      'slidebox_width' => '1000',


      'transition_style' => 'fade',


      'transition_speed' => '2',


      'slide_duration' => '5',


      'slideshow_navigation' => 'navnone'


    );


    update_option( 'wsslides_options', $ws_defaults_args );


  }


}


// Adds function to load slideshow in theme


function ws_slideshow( $slideshow = '', $metadata = '' ) {


  if ( file_exists( get_stylesheet_directory() . "/ws-slideshow.php" ) ) {


    include( STYLESHEETPATH . '/ws-slideshow.php' );


  } elseif ( file_exists( get_template_directory() . "/ws-slideshow.php" ) ) {


    include( TEMPLATEPATH . '/ws-slideshow.php' );


  }


  else {


    include( 'includes/ws-slideshow.php' );


  }


}


/* To load the slideshow, add this line to your theme:



	



			<?php if(function_exists('ws_slideshow')) { ws_slideshow(); } ?>



	



		*/


// Adds shortcode to load slideshow in content


function ws_slideshow_shortcode( $ws_atts ) {


  extract( shortcode_atts( array(


    'slideshow' => '',


    'metadata' => '',


  ), $ws_atts ) );


  $slideshow_att = $slideshow;


  $metadata_att = $metadata;


  ob_start();


  ws_slideshow( $slideshow = $slideshow_att, $metadata = $metadata_att );


  $ws_slideshow_content = ob_get_clean();


  return $ws_slideshow_content;


}


add_shortcode( 'ws_slideshow', 'ws_slideshow_shortcode' );


/* To load the slideshow, add this line to your page or post:



	



			[ws_slideshow]



	



		*/


// Adds widget to load slideshow in sidebar

/*
add_action( 'widgets_init', 'wsslides_register_widget' );


function wsslides_register_widget() {


  register_widget( 'wsslides_widget' );


}
*/

class wsslides_widget extends WP_Widget {


  function wsslides_widget() {


    $widget_ops = array(


      'classname' => 'ws-slides-widget',


      'description' => __( 'Add a slideshow widget to a sidebar', 'ws-slides' )


    );


    $control_ops = array( 'id_base' => 'ws-slides-widget' );


    $this->WP_Widget( 'ws-slides-widget', __( 'ws Slides Widget', 'ws-slides' ), $widget_ops, $control_ops );


  }


  function widget( $args, $instance ) {


    extract( $args );


    $title = apply_filters( 'widget_title', $instance[ 'title' ] );


    $slideshow_arg = $instance[ 'slideshow' ];


    $metadata_arg = $instance[ 'metadata' ];


    echo $before_widget;


    if ( $title ) {


      echo $before_title . $title . $after_title;


    }


    ws_slideshow( $slideshow = $slideshow_arg, $metadata = $metadata_arg );


    echo $after_widget;


  }


  function update( $new_instance, $old_instance ) {


    $instance = $old_instance;


    $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );


    $instance[ 'slideshow' ] = strip_tags( $new_instance[ 'slideshow' ] );


    $instance[ 'metadata' ] = strip_tags( $new_instance[ 'metadata' ] );


    return $instance;


  }


  function form( $instance ) {


    $defaults = array(


      'title' => '',


      'slideshow' => '',


      'metadata' => ''


    );


    $instance = wp_parse_args( ( array )$instance, $defaults );


    echo '<p><label for="' . $this->get_field_id( 'title' ) . '">' . __( 'Title:', 'ws-slides' ) . '</label>



			<input type="text" class="widefat" id="' . $this->get_field_id( 'title' ) . '" name="' . $this->get_field_name( 'title' ) . '" value="' . $instance[ 'title' ] . '" /></p>';


    // If the slideshow taxonomy has terms, create a select list of those terms


    $slideshow_terms = get_terms( 'slideshow' );


    $slideshow_terms_count = count( $slideshow_terms );


    $slideshow_value = $instance[ 'slideshow' ];


    if ( $slideshow_terms_count > 0 ) {


      echo '<p><label for="' . $this->get_field_id( 'slideshow' ) . '">' . __( 'Slideshow:', 'ws-slides' ) . '</label>';


      echo '<select name="' . $this->get_field_name( 'slideshow' ) . '" id="' . $this->get_field_id( 'slideshow' ) . '" class="widefat">';


      echo '<option value="">All Slides</option>';


      foreach ( $slideshow_terms as $slideshow_terms ) {


        if ( $slideshow_terms->slug == $slideshow_value ) {


          echo '<option selected="selected" value="' . $slideshow_terms->slug . '">' . $slideshow_terms->name . '</option>';


        } else {


          echo '<option value="' . $slideshow_terms->slug . '">' . $slideshow_terms->name . '</option>';


        }


      }


      echo '</select>';


    }


    echo '<p><label for="' . $this->get_field_id( 'metadata' ) . '">' . __( 'Metadata:', 'ws-slides' ) . '</label>



			<input type="text" class="widefat" id="' . $this->get_field_id( 'metadata' ) . '" name="' . $this->get_field_name( 'metadata' ) . '" value="' . $instance[ 'metadata' ] . '" /></p>';


  }


}


add_post_type_support( 'slide', 'editor' );


?>